lcvtoolbox.integrations.cvat.api.compile\_job.CvatJob
=====================================================

.. currentmodule:: lcvtoolbox.integrations.cvat.api.compile_job

.. autoclass:: CvatJob
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatJob.__init__
      ~CvatJob.create_annotated_images
      ~CvatJob.download_images
      ~CvatJob.get_image
      ~CvatJob.get_shapes_for_frame
      ~CvatJob.get_tags_for_frame
      ~CvatJob.process
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatJob.annotated_images
      ~CvatJob.annotations
      ~CvatJob.details
      ~CvatJob.frames
      ~CvatJob.frames_names
      ~CvatJob.frames_numbers
      ~CvatJob.length
      ~CvatJob.metainformation
      ~CvatJob.project_id
      ~CvatJob.task_details
      ~CvatJob.task_id
   
   